@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2022, University of Tennessee. All rights reserved.
+// Copyright (c) 2017-2023, University of Tennessee. All rights reserved.
 // SPDX-License-Identifier: BSD-3-Clause
 // This program is free software: you can redistribute it and/or modify it under
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
@@ -8,7 +8,7 @@
 
 #include <stdint.h>
 
-// -----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 #if defined(FORTRAN_UPPER)
     #define FORTRAN_NAME( lower, UPPER ) UPPER
 #elif defined(FORTRAN_LOWER)
@@ -18,7 +18,7 @@
     #define FORTRAN_NAME( lower, UPPER ) lower ## _
 #endif
 
-// -----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 #if defined(BLAS_ILP64) || defined(LAPACK_ILP64)
     typedef int64_t blas_int;
     typedef int64_t lapack_int;
@@ -27,4 +27,13 @@
     typedef int lapack_int;
 #endif
 
+//------------------------------------------------------------------------------
+#ifndef BLAS_FORTRAN_STRLEN_END
+#define BLAS_FORTRAN_STRLEN_END
+#endif
+
+#ifndef LAPACK_FORTRAN_STRLEN_END
+#define LAPACK_FORTRAN_STRLEN_END
+#endif
+
 #endif // CONFIG_H
