@@ -44,6 +44,9 @@ void dot(
         memset( &element, 0, sizeof( element ) );
         element = { n };
         counter::insert( element, counter::Id::dev_dot );
+
+        double gflops = 1e9 * blas::Gflop< scalar_t >::dot( n );
+        counter::inc_flop_count( (long long int)gflops );
     #endif
 
     // convert arguments
