@@ -24,8 +24,8 @@ void test_batch_herk_work( Params& params, bool run )
     blas::Layout layout = params.layout();
     blas::Op trans_      = params.trans();
     blas::Uplo uplo_     = params.uplo();
-    real_t alpha_        = params.alpha();  // note: real
-    real_t beta_         = params.beta();   // note: real
+    real_t alpha_        = params.alpha.get<real_t>();  // note: real
+    real_t beta_         = params.beta.get<real_t>();   // note: real
     int64_t n_           = params.dim.n();
     int64_t k_           = params.dim.k();
     size_t  batch       = params.batch();
@@ -89,7 +89,7 @@ void test_batch_herk_work( Params& params, bool run )
 
     for (size_t s = 0; s < batch; ++s) {
         Anorm[s] = lapack_lange( "f", Am, An, Aarray[s], lda_, work );
-        Cnorm[s] = lapack_lansy( "f", uplo2str(uplo_), n_, Carray[s], ldc_, work );
+        Cnorm[s] = lapack_lansy( "f", to_c_string( uplo_ ), n_, Carray[s], ldc_, work );
     }
 
     // decide error checking mode
