@@ -26,7 +26,7 @@ void test_batch_trmm_work( Params& params, bool run )
     blas::Uplo uplo_    = params.uplo();
     blas::Op trans_     = params.trans();
     blas::Diag diag_    = params.diag();
-    scalar_t alpha_     = params.alpha();
+    scalar_t alpha_     = params.alpha.get<scalar_t>();
     int64_t m_          = params.dim.m();
     int64_t n_          = params.dim.n();
     size_t  batch       = params.batch();
@@ -92,7 +92,7 @@ void test_batch_trmm_work( Params& params, bool run )
     real_t* Bnorm = new real_t[ batch ];
 
     for (size_t s = 0; s < batch; ++s) {
-        Anorm[s] = lapack_lantr( "f", uplo2str(uplo_), diag2str(diag_), Am, Am, Aarray[s], lda_, work );
+        Anorm[s] = lapack_lantr( "f", to_c_string( uplo_ ), to_c_string( diag_ ), Am, Am, Aarray[s], lda_, work );
         Bnorm[s] = lapack_lange( "f", Bm, Bn, Barray[s], ldb_, work );
     }
 
