@@ -23,7 +23,7 @@ void test_her_work( Params& params, bool run )
     // get & mark input values
     blas::Layout layout = params.layout();
     blas::Uplo uplo = params.uplo();
-    real_t alpha    = params.alpha();  // note: real
+    real_t alpha    = params.alpha.get<real_t>();  // note: real
     int64_t n       = params.dim.n();
     int64_t incx    = params.incx();
     int64_t align   = params.align();
@@ -60,7 +60,7 @@ void test_her_work( Params& params, bool run )
 
     // norms for error check
     real_t work[1];
-    real_t Anorm = lapack_lanhe( "f", uplo2str(uplo), n, A, lda, work );
+    real_t Anorm = lapack_lanhe( "f", to_c_string( uplo ), n, A, lda, work );
     real_t Xnorm = cblas_nrm2( n, x, std::abs(incx) );
 
     // test error exits
