@@ -10,16 +10,18 @@
 #include "print_matrix.hh"
 
 // -----------------------------------------------------------------------------
-template <typename T>
+template <typename scalar_t>
 void test_scal_work( Params& params, bool run )
 {
     using namespace testsweeper;
+    using blas::max;
+    using std::abs;
     using std::real;
     using std::imag;
-    using real_t = blas::real_type< T >;
+    using real_t = blas::real_type< scalar_t >;
 
     // get & mark input values
-    T alpha         = params.alpha();
+    scalar_t alpha  = params.alpha.get<scalar_t>();
     int64_t n       = params.dim.n();
     int64_t incx    = params.incx();
     int64_t verbose = params.verbose();
@@ -41,8 +43,8 @@ void test_scal_work( Params& params, bool run )
 
     // setup
     size_t size_x = (n - 1) * std::abs(incx) + 1;
-    T* x    = new T[ size_x ];
-    T* xref = new T[ size_x ];
+    scalar_t* x    = new scalar_t[ size_x ];
+    scalar_t* xref = new scalar_t[ size_x ];
 
     int64_t idist = 1;
     int iseed[4] = { 0, 0, 0, 1 };
@@ -71,8 +73,8 @@ void test_scal_work( Params& params, bool run )
     blas::scal( n, alpha, x, incx );
     time = get_wtime() - time;
 
-    double gflop = blas::Gflop< T >::scal( n );
-    double gbyte = blas::Gbyte< T >::scal( n );
+    double gflop = blas::Gflop< scalar_t >::scal( n );
+    double gbyte = blas::Gbyte< scalar_t >::scal( n );
     params.time()   = time * 1000;  // msec
     params.gflops() = gflop / time;
     params.gbytes() = gbyte / time;
@@ -101,13 +103,13 @@ void test_scal_work( Params& params, bool run )
         real_t error = 0;
         int64_t ix = (incx > 0 ? 0 : (-n + 1)*incx);
         for (int64_t i = 0; i < n; ++i) {
-            error = std::max( error, std::abs( (xref[ix] - x[ix]) / xref[ix] ));
+            error = max( error, abs( (xref[ix] - x[ix]) / xref[ix] ));
             ix += incx;
         }
         params.error() = error;
 
         // complex needs extra factor; see Higham, 2002, sec. 3.6.
-        if (blas::is_complex<T>::value) {
+        if (blas::is_complex<scalar_t>::value) {
             error /= 2*sqrt(2);
         }
 
