@@ -27,8 +27,8 @@ void test_syrk_work( Params& params, bool run )
     blas::Layout layout = params.layout();
     blas::Op trans  = params.trans();
     blas::Uplo uplo = params.uplo();
-    scalar_t alpha  = params.alpha();
-    scalar_t beta   = params.beta();
+    scalar_t alpha  = params.alpha.get<scalar_t>();
+    scalar_t beta   = params.beta.get<scalar_t>();
     int64_t n       = params.dim.n();
     int64_t k       = params.dim.k();
     int64_t align   = params.align();
@@ -64,7 +64,7 @@ void test_syrk_work( Params& params, bool run )
     // norms for error check
     real_t work[1];
     real_t Anorm = lapack_lange( "f", Am, An, A, lda, work );
-    real_t Cnorm = lapack_lansy( "f", uplo2str(uplo), n, C, ldc, work );
+    real_t Cnorm = lapack_lansy( "f", to_c_string( uplo ), n, C, ldc, work );
 
     // test error exits
     assert_throw( blas::syrk( Layout(0), uplo,    trans,  n,  k, alpha, A, lda, beta, C, ldc ), blas::Error );
@@ -93,7 +93,7 @@ void test_syrk_work( Params& params, bool run )
                 "layout %c, uplo %c, trans %c\n"
                 "A An=%5lld, An=%5lld, lda=%5lld, size=%10lld, norm %.2e\n"
                 "C  n=%5lld,  n=%5lld, ldc=%5lld, size=%10lld, norm %.2e\n",
-                layout2char(layout), uplo2char(uplo), op2char(trans),
+                to_char( layout ), to_char( uplo ), to_char( trans ),
                 llong( Am ), llong( An ), llong( lda ), llong( size_A ), Anorm,
                 llong( n ), llong( n ), llong( ldc ), llong( size_C ), Cnorm );
     }
