@@ -29,7 +29,7 @@ void test_trmm_work( Params& params, bool run )
     blas::Uplo uplo = params.uplo();
     blas::Op trans  = params.trans();
     blas::Diag diag = params.diag();
-    scalar_t alpha  = params.alpha();
+    scalar_t alpha  = params.alpha.get<scalar_t>();
     int64_t m       = params.dim.m();
     int64_t n       = params.dim.n();
     int64_t align   = params.align();
@@ -66,7 +66,7 @@ void test_trmm_work( Params& params, bool run )
 
     // norms for error check
     real_t work[1];
-    real_t Anorm = lapack_lantr( "f", uplo2str(uplo), diag2str(diag),
+    real_t Anorm = lapack_lantr( "f", to_c_string( uplo ), to_c_string( diag ),
                                  Am, Am, A, lda, work );
     real_t Bnorm = lapack_lange( "f", Bm, Bn, B, ldb, work );
 
