@@ -23,6 +23,7 @@ void test_trsv_work( Params& params, bool run )
     using blas::Diag;
     using scalar_t = blas::scalar_type< TA, TX >;
     using real_t   = blas::real_type< scalar_t >;
+    using std::swap;
 
     // get & mark input values
     blas::Layout layout = params.layout();
@@ -82,12 +83,12 @@ void test_trsv_work( Params& params, bool run )
         A[ i + i*lda ] += n;
     }
     int64_t info = 0;
-    lapack_potrf( uplo2str(uplo), n, A, lda, &info );
+    lapack_potrf( to_c_string( uplo ), n, A, lda, &info );
     require( info == 0 );
 
     // norms for error check
     real_t work[1];
-    real_t Anorm = lapack_lantr( "f", uplo2str(uplo), diag2str(diag),
+    real_t Anorm = lapack_lantr( "f", to_c_string( uplo ), to_c_string( diag ),
                                  n, n, A, lda, work );
     real_t Xnorm = cblas_nrm2( n, x, std::abs(incx) );
 
@@ -95,7 +96,7 @@ void test_trsv_work( Params& params, bool run )
     if (layout == Layout::RowMajor) {
         for (int64_t j = 0; j < n; ++j) {
             for (int64_t i = 0; i < j; ++i) {
-                std::swap( A[ i + j*lda ], A[ j + i*lda ] );
+                swap( A[ i + j*lda ], A[ j + i*lda ] );
             }
         }
     }
