@@ -14,61 +14,101 @@ using testsweeper::get_wtime;
 void test_enums()
 {
     printf( "%s\n", __func__ );
+    int verbose = 0;  // used in assert_throw
 
     using str = std::string;
 
-    require( blas::layout2char( blas::Layout::ColMajor ) == 'C' );
-    require( blas::layout2char( blas::Layout::RowMajor ) == 'R' );
-    require( blas::layout2str( blas::Layout::ColMajor ) == str("col") );
-    require( blas::layout2str( blas::Layout::RowMajor ) == str("row") );
-    require( blas::char2layout( 'C' ) == blas::Layout::ColMajor );
-    require( blas::char2layout( 'c' ) == blas::Layout::ColMajor );
-    require( blas::char2layout( 'R' ) == blas::Layout::RowMajor );
-    require( blas::char2layout( 'r' ) == blas::Layout::RowMajor );
+    require( to_char( blas::Layout::ColMajor ) == 'C' );
+    require( to_char( blas::Layout::RowMajor ) == 'R' );
+    require( to_c_string( blas::Layout::ColMajor ) == str("col") );
+    require( to_c_string( blas::Layout::RowMajor ) == str("row") );
+    require( to_string( blas::Layout::ColMajor ) == "col" );
+    require( to_string( blas::Layout::RowMajor ) == "row" );
 
-    require( blas::op2char( blas::Op::NoTrans   ) == 'N' );
-    require( blas::op2char( blas::Op::Trans     ) == 'T' );
-    require( blas::op2char( blas::Op::ConjTrans ) == 'C' );
-    require( blas::op2str( blas::Op::NoTrans   ) == str("notrans") );
-    require( blas::op2str( blas::Op::Trans     ) == str("trans") );
-    require( blas::op2str( blas::Op::ConjTrans ) == str("conj") );
-    require( blas::char2op( 'N' ) == blas::Op::NoTrans   );
-    require( blas::char2op( 'n' ) == blas::Op::NoTrans   );
-    require( blas::char2op( 'T' ) == blas::Op::Trans     );
-    require( blas::char2op( 't' ) == blas::Op::Trans     );
-    require( blas::char2op( 'C' ) == blas::Op::ConjTrans );
-    require( blas::char2op( 'c' ) == blas::Op::ConjTrans );
+    blas::Layout layout;
+    from_string( "C", &layout );  require( layout == blas::Layout::ColMajor );
+    from_string( "c", &layout );  require( layout == blas::Layout::ColMajor );
+    from_string( "R", &layout );  require( layout == blas::Layout::RowMajor );
+    from_string( "r", &layout );  require( layout == blas::Layout::RowMajor );
+    from_string( "colmajor", &layout );  require( layout == blas::Layout::ColMajor );
+    from_string( "rowmajor", &layout );  require( layout == blas::Layout::RowMajor );
+    assert_throw( from_string( "xyz", &layout ), blas::Error );
 
-    require( blas::uplo2char( blas::Uplo::Upper   ) == 'U' );
-    require( blas::uplo2char( blas::Uplo::Lower   ) == 'L' );
-    require( blas::uplo2char( blas::Uplo::General ) == 'G' );
-    require( blas::uplo2str( blas::Uplo::Upper   ) == str("upper") );
-    require( blas::uplo2str( blas::Uplo::Lower   ) == str("lower") );
-    require( blas::uplo2str( blas::Uplo::General ) == str("general") );
-    require( blas::char2uplo( 'U' ) == blas::Uplo::Upper   );
-    require( blas::char2uplo( 'u' ) == blas::Uplo::Upper   );
-    require( blas::char2uplo( 'L' ) == blas::Uplo::Lower   );
-    require( blas::char2uplo( 'l' ) == blas::Uplo::Lower   );
-    require( blas::char2uplo( 'G' ) == blas::Uplo::General );
-    require( blas::char2uplo( 'g' ) == blas::Uplo::General );
+    require( to_char( blas::Op::NoTrans   ) == 'N' );
+    require( to_char( blas::Op::Trans     ) == 'T' );
+    require( to_char( blas::Op::ConjTrans ) == 'C' );
+    require( to_c_string( blas::Op::NoTrans   ) == str("notrans") );
+    require( to_c_string( blas::Op::Trans     ) == str("trans") );
+    require( to_c_string( blas::Op::ConjTrans ) == str("conj") );
+    require( to_string( blas::Op::NoTrans   ) == "notrans" );
+    require( to_string( blas::Op::Trans     ) == "trans" );
+    require( to_string( blas::Op::ConjTrans ) == "conj" );
 
-    require( blas::diag2char( blas::Diag::NonUnit ) == 'N' );
-    require( blas::diag2char( blas::Diag::Unit    ) == 'U' );
-    require( blas::diag2str( blas::Diag::NonUnit ) == str("nonunit") );
-    require( blas::diag2str( blas::Diag::Unit    ) == str("unit") );
-    require( blas::char2diag( 'N' ) == blas::Diag::NonUnit );
-    require( blas::char2diag( 'n' ) == blas::Diag::NonUnit );
-    require( blas::char2diag( 'U' ) == blas::Diag::Unit    );
-    require( blas::char2diag( 'u' ) == blas::Diag::Unit    );
+    blas::Op op;
+    from_string( "N", &op );  require( op == blas::Op::NoTrans   );
+    from_string( "n", &op );  require( op == blas::Op::NoTrans   );
+    from_string( "T", &op );  require( op == blas::Op::Trans     );
+    from_string( "t", &op );  require( op == blas::Op::Trans     );
+    from_string( "C", &op );  require( op == blas::Op::ConjTrans );
+    from_string( "c", &op );  require( op == blas::Op::ConjTrans );
+    from_string( "notrans",   &op );  require( op == blas::Op::NoTrans   );
+    from_string( "trans",     &op );  require( op == blas::Op::Trans     );
+    from_string( "conjtrans", &op );  require( op == blas::Op::ConjTrans );
+    assert_throw( from_string( "xyz", &op ), blas::Error );
 
-    require( blas::side2char( blas::Side::Left  ) == 'L' );
-    require( blas::side2char( blas::Side::Right ) == 'R' );
-    require( blas::side2str( blas::Side::Left  ) == str("left") );
-    require( blas::side2str( blas::Side::Right ) == str("right") );
-    require( blas::char2side( 'L' ) == blas::Side::Left  );
-    require( blas::char2side( 'l' ) == blas::Side::Left  );
-    require( blas::char2side( 'R' ) == blas::Side::Right );
-    require( blas::char2side( 'r' ) == blas::Side::Right );
+    require( to_char( blas::Uplo::Upper   ) == 'U' );
+    require( to_char( blas::Uplo::Lower   ) == 'L' );
+    require( to_char( blas::Uplo::General ) == 'G' );
+    require( to_c_string( blas::Uplo::Upper   ) == str("upper") );
+    require( to_c_string( blas::Uplo::Lower   ) == str("lower") );
+    require( to_c_string( blas::Uplo::General ) == str("general") );
+    require( to_string( blas::Uplo::Upper   ) == "upper" );
+    require( to_string( blas::Uplo::Lower   ) == "lower" );
+    require( to_string( blas::Uplo::General ) == "general" );
+
+    blas::Uplo uplo;
+    from_string( "U", &uplo );  require( uplo == blas::Uplo::Upper   );
+    from_string( "u", &uplo );  require( uplo == blas::Uplo::Upper   );
+    from_string( "L", &uplo );  require( uplo == blas::Uplo::Lower   );
+    from_string( "l", &uplo );  require( uplo == blas::Uplo::Lower   );
+    from_string( "G", &uplo );  require( uplo == blas::Uplo::General );
+    from_string( "g", &uplo );  require( uplo == blas::Uplo::General );
+    from_string( "upper",   &uplo );  require( uplo == blas::Uplo::Upper   );
+    from_string( "lower",   &uplo );  require( uplo == blas::Uplo::Lower   );
+    from_string( "general", &uplo );  require( uplo == blas::Uplo::General );
+    assert_throw( from_string( "xyz", &uplo ), blas::Error );
+
+    require( to_char( blas::Diag::NonUnit ) == 'N' );
+    require( to_char( blas::Diag::Unit    ) == 'U' );
+    require( to_c_string( blas::Diag::NonUnit ) == str("nonunit") );
+    require( to_c_string( blas::Diag::Unit    ) == str("unit") );
+    require( to_string( blas::Diag::NonUnit ) == "nonunit" );
+    require( to_string( blas::Diag::Unit    ) == "unit" );
+
+    blas::Diag diag;
+    from_string( "N", &diag );  require( diag == blas::Diag::NonUnit );
+    from_string( "n", &diag );  require( diag == blas::Diag::NonUnit );
+    from_string( "U", &diag );  require( diag == blas::Diag::Unit    );
+    from_string( "u", &diag );  require( diag == blas::Diag::Unit    );
+    from_string( "nonunit", &diag );  require( diag == blas::Diag::NonUnit );
+    from_string( "unit",    &diag );  require( diag == blas::Diag::Unit    );
+    assert_throw( from_string( "xyz", &diag ), blas::Error );
+
+    require( to_char( blas::Side::Left  ) == 'L' );
+    require( to_char( blas::Side::Right ) == 'R' );
+    require( to_c_string( blas::Side::Left  ) == str("left") );
+    require( to_c_string( blas::Side::Right ) == str("right") );
+    require( to_string( blas::Side::Left  ) == "left" );
+    require( to_string( blas::Side::Right ) == "right" );
+
+    blas::Side side;
+    from_string( "L", &side );  require( side == blas::Side::Left  );
+    from_string( "l", &side );  require( side == blas::Side::Left  );
+    from_string( "R", &side );  require( side == blas::Side::Right );
+    from_string( "r", &side );  require( side == blas::Side::Right );
+    from_string( "left",  &side );  require( side == blas::Side::Left  );
+    from_string( "right", &side );  require( side == blas::Side::Right );
+    assert_throw( from_string( "xyz", &side ), blas::Error );
 }
 
 // -----------------------------------------------------------------------------
